@@ -123,6 +123,10 @@ def aggregate_by_page_asyncio(
     if open_log:
         log_file = open(log_file, "a+")
 
+    async def parse_(loop, chunk):
+        run_func = lambda: parse_func(chunk)
+        await loop.run_in_executor(None, run_func)
+
     current_last_id = start_id
     current_page = 0
     count = coll.find({"_id": {"$gt": current_last_id}}).count()
@@ -140,7 +144,7 @@ def aggregate_by_page_asyncio(
         wprint(log_msg)
         # 查询
         condition = [
-            {"$sort": {"_id": 1}},
+            #  {"$sort": {"_id": 1}},
             {"$match": {"_id": {"$gt": current_last_id}}},
             {"$limit": page_size},
         ]
@@ -151,26 +155,44 @@ def aggregate_by_page_asyncio(
             else coll.aggregate(pipeline=condition, session=session)
         )
 
-        find_cost_time = time.time() - start_time
-        log_msg = "# find this page data cost time: {}s".format(find_cost_time)
+        data = [x for x in cursor]
+
+        log_msg = "# find this page data cost time: {}s".format(
+            time.time() - start_time
+        )
         wprint(log_msg)
 
-        data = [x for x in cursor]
         # 更新 current_last_id
         current_last_id = data[-1]["_id"]
         log_msg = "# current_last_id --> {}".format(current_last_id)
         wprint(log_msg)
+
+        log_msg = "# find this page data cost time: {}s".format(
+            time.time() - start_time
+        )
+        wprint(log_msg)
+
         # 翻页
         current_page += 1
         # 处理数据
         if open_async:
             loop = asyncio.get_event_loop()
             chunks = gb.chunks(data, slave_num)
-            #  coroutines = [parse_func(chunk) for chunk in chunks]
-            tasks = [asyncio.ensure_future(parse_func(chunk)) for chunk in chunks]
-            loop.run_until_complete(asyncio.wait(tasks))
+            try:
+                loop.run_until_complete(
+                    asyncio.gather(*[parse_(loop, chunk) for chunk in chunks])
+                )
+            finally:
+                loop.close()
+                chunks.clear()
         else:
             parse_func(data)
+
+        log_msg = "# find this page data cost time: {}s".format(
+            time.time() - start_time
+        )
+        wprint(log_msg)
+
         data_size += len(data)
         log_msg = "# elapsed time: {}s".format(time.time() - start_time)
         wprint(log_msg)
